@@ -45,22 +45,22 @@ public class ClassGen extends AccessFlags implements Cloneable {
 
     /* Corresponds to the fields found in a JavaClass object.
      */
-    private String class_name;
-    private String super_class_name;
-    private final String file_name;
-    private int class_name_index = -1;
+    private String className;
+    private String superClassName;
+    private final String fileName;
+    private int classNameIndex = -1;
     private int superclass_name_index = -1;
     private int major = Const.MAJOR_1_1;
     private int minor = Const.MINOR_1_1;
     private ConstantPoolGen cp; // Template for building up constant pool
     // ArrayLists instead of arrays to gather fields, methods, etc.
-    private final List<Field> field_vec = new ArrayList<>();
-    private final List<Method> method_vec = new ArrayList<>();
-    private final List<Attribute> attribute_vec = new ArrayList<>();
-    private final List<String> interface_vec = new ArrayList<>();
-    private final List<AnnotationEntryGen> annotation_vec = new ArrayList<>();
+    private final List<Field> fieldList = new ArrayList<>();
+    private final List<Method> methodList = new ArrayList<>();
+    private final List<Attribute> attributeList = new ArrayList<>();
+    private final List<String> interfaceList = new ArrayList<>();
+    private final List<AnnotationEntryGen> annotationList = new ArrayList<>();
 
-    private static BCELComparator _cmp = new BCELComparator() {
+    private static BCELComparator bcelComparator = new BCELComparator() {
 
         @Override
         public boolean equals( final Object o1, final Object o2 ) {
@@ -80,27 +80,27 @@ public class ClassGen extends AccessFlags implements Cloneable {
 
     /** Convenience constructor to set up some important values initially.
      *
-     * @param class_name fully qualified class name
-     * @param super_class_name fully qualified superclass name
-     * @param file_name source file name
-     * @param access_flags access qualifiers
+     * @param className fully qualified class name
+     * @param superClassName fully qualified superclass name
+     * @param fileName source file name
+     * @param accessFlags access qualifiers
      * @param interfaces implemented interfaces
      * @param cp constant pool to use
      */
-    public ClassGen(final String class_name, final String super_class_name, final String file_name, final int access_flags,
+    public ClassGen(final String className, final String superClassName, final String fileName, final int accessFlags,
             final String[] interfaces, final ConstantPoolGen cp) {
-        super(access_flags);
-        this.class_name = class_name;
-        this.super_class_name = super_class_name;
-        this.file_name = file_name;
+        super(accessFlags);
+        this.className = className;
+        this.superClassName = superClassName;
+        this.fileName = fileName;
         this.cp = cp;
         // Put everything needed by default into the constant pool and the vectors
-        if (file_name != null) {
-            addAttribute(new SourceFile(cp.addUtf8("SourceFile"), 2, cp.addUtf8(file_name), cp
+        if (fileName != null) {
+            addAttribute(new SourceFile(cp.addUtf8("SourceFile"), 2, cp.addUtf8(fileName), cp
                     .getConstantPool()));
         }
-        class_name_index = cp.addClass(class_name);
-        superclass_name_index = cp.addClass(super_class_name);
+        classNameIndex = cp.addClass(className);
+        superclass_name_index = cp.addClass(superClassName);
         if (interfaces != null) {
             for (final String interface1 : interfaces) {
                 addInterface(interface1);
@@ -111,15 +111,15 @@ public class ClassGen extends AccessFlags implements Cloneable {
 
     /** Convenience constructor to set up some important values initially.
      *
-     * @param class_name fully qualified class name
-     * @param super_class_name fully qualified superclass name
-     * @param file_name source file name
-     * @param access_flags access qualifiers
+     * @param className fully qualified class name
+     * @param superClassName fully qualified superclass name
+     * @param fileName source file name
+     * @param accessFlags access qualifiers
      * @param interfaces implemented interfaces
      */
-    public ClassGen(final String class_name, final String super_class_name, final String file_name, final int access_flags,
+    public ClassGen(final String className, final String superClassName, final String fileName, final int accessFlags,
             final String[] interfaces) {
-        this(class_name, super_class_name, file_name, access_flags, interfaces,
+        this(className, superClassName, fileName, accessFlags, interfaces,
                 new ConstantPoolGen());
     }
 
@@ -130,11 +130,11 @@ public class ClassGen extends AccessFlags implements Cloneable {
      */
     public ClassGen(final JavaClass clazz) {
         super(clazz.getAccessFlags());
-        class_name_index = clazz.getClassNameIndex();
+        classNameIndex = clazz.getClassNameIndex();
         superclass_name_index = clazz.getSuperclassNameIndex();
-        class_name = clazz.getClassName();
-        super_class_name = clazz.getSuperclassName();
-        file_name = clazz.getSourceFileName();
+        className = clazz.getClassName();
+        superClassName = clazz.getSuperclassName();
+        fileName = clazz.getSourceFileName();
         cp = new ConstantPoolGen(clazz.getConstantPool());
         major = clazz.getMajor();
         minor = clazz.getMinor();
@@ -202,18 +202,18 @@ public class ClassGen extends AccessFlags implements Cloneable {
         final Field[] fields = getFields();
         final Method[] methods = getMethods();
         Attribute[] attributes = null;
-        if (annotation_vec.isEmpty()) {
+        if (annotationList.isEmpty()) {
             attributes = getAttributes();
         } else {
             // TODO: Sometime later, trash any attributes called 'RuntimeVisibleAnnotations' or 'RuntimeInvisibleAnnotations'
             final Attribute[] annAttributes  = AnnotationEntryGen.getAnnotationAttributes(cp, getAnnotationEntries());
-            attributes = new Attribute[attribute_vec.size()+annAttributes.length];
-            attribute_vec.toArray(attributes);
-            System.arraycopy(annAttributes,0,attributes,attribute_vec.size(),annAttributes.length);
+            attributes = new Attribute[attributeList.size()+annAttributes.length];
+            attributeList.toArray(attributes);
+            System.arraycopy(annAttributes,0,attributes,attributeList.size(),annAttributes.length);
         }
         // Must be last since the above calls may still add something to it
         final ConstantPool _cp = this.cp.getFinalConstantPool();
-        return new JavaClass(class_name_index, superclass_name_index, file_name, major, minor,
+        return new JavaClass(classNameIndex, superclass_name_index, fileName, major, minor,
                 super.getAccessFlags(), _cp, interfaces, fields, methods, attributes);
     }
 
@@ -223,7 +223,7 @@ public class ClassGen extends AccessFlags implements Cloneable {
      * @param name interface to implement (fully qualified class name)
      */
     public void addInterface( final String name ) {
-        interface_vec.add(name);
+        interfaceList.add(name);
     }
 
 
@@ -232,7 +232,7 @@ public class ClassGen extends AccessFlags implements Cloneable {
      * @param name interface to remove (fully qualified name)
      */
     public void removeInterface( final String name ) {
-        interface_vec.remove(name);
+        interfaceList.remove(name);
     }
 
 
@@ -272,11 +272,11 @@ public class ClassGen extends AccessFlags implements Cloneable {
      * @param a attribute to add
      */
     public void addAttribute( final Attribute a ) {
-        attribute_vec.add(a);
+        attributeList.add(a);
     }
 
     public void addAnnotationEntry(final AnnotationEntryGen a) {
-        annotation_vec.add(a);
+        annotationList.add(a);
     }
 
 
@@ -285,7 +285,7 @@ public class ClassGen extends AccessFlags implements Cloneable {
      * @param m method to add
      */
     public void addMethod( final Method m ) {
-        method_vec.add(m);
+        methodList.add(m);
     }
 
 
@@ -298,10 +298,10 @@ public class ClassGen extends AccessFlags implements Cloneable {
     public void addEmptyConstructor( final int access_flags ) {
         final InstructionList il = new InstructionList();
         il.append(InstructionConst.THIS); // Push `this'
-        il.append(new INVOKESPECIAL(cp.addMethodref(super_class_name, "<init>", "()V")));
+        il.append(new INVOKESPECIAL(cp.addMethodref(superClassName, "<init>", "()V")));
         il.append(InstructionConst.RETURN);
         final MethodGen mg = new MethodGen(access_flags, Type.VOID, Type.NO_ARGS, null, "<init>",
-                class_name, il, cp);
+                className, il, cp);
         mg.setMaxStack(1);
         addMethod(mg.getMethod());
     }
@@ -312,19 +312,19 @@ public class ClassGen extends AccessFlags implements Cloneable {
      * @param f field to add
      */
     public void addField( final Field f ) {
-        field_vec.add(f);
+        fieldList.add(f);
     }
 
 
     public boolean containsField( final Field f ) {
-        return field_vec.contains(f);
+        return fieldList.contains(f);
     }
 
 
     /** @return field object with given name, or null
      */
     public Field containsField( final String name ) {
-        for (final Field f : field_vec) {
+        for (final Field f : fieldList) {
             if (f.getName().equals(name)) {
                 return f;
             }
@@ -336,7 +336,7 @@ public class ClassGen extends AccessFlags implements Cloneable {
     /** @return method object with given name and signature, or null
      */
     public Method containsMethod( final String name, final String signature ) {
-        for (final Method m : method_vec) {
+        for (final Method m : methodList) {
             if (m.getName().equals(name) && m.getSignature().equals(signature)) {
                 return m;
             }
@@ -350,7 +350,7 @@ public class ClassGen extends AccessFlags implements Cloneable {
      * @param a attribute to remove
      */
     public void removeAttribute( final Attribute a ) {
-        attribute_vec.remove(a);
+        attributeList.remove(a);
     }
 
 
@@ -359,7 +359,7 @@ public class ClassGen extends AccessFlags implements Cloneable {
      * @param m method to remove
      */
     public void removeMethod( final Method m ) {
-        method_vec.remove(m);
+        methodList.remove(m);
     }
 
 
@@ -370,11 +370,11 @@ public class ClassGen extends AccessFlags implements Cloneable {
         if (new_ == null) {
             throw new ClassGenException("Replacement method must not be null");
         }
-        final int i = method_vec.indexOf(old);
+        final int i = methodList.indexOf(old);
         if (i < 0) {
-            method_vec.add(new_);
+            methodList.add(new_);
         } else {
-            method_vec.set(i, new_);
+            methodList.set(i, new_);
         }
     }
 
@@ -386,11 +386,11 @@ public class ClassGen extends AccessFlags implements Cloneable {
         if (new_ == null) {
             throw new ClassGenException("Replacement method must not be null");
         }
-        final int i = field_vec.indexOf(old);
+        final int i = fieldList.indexOf(old);
         if (i < 0) {
-            field_vec.add(new_);
+            fieldList.add(new_);
         } else {
-            field_vec.set(i, new_);
+            fieldList.set(i, new_);
         }
     }
 
@@ -400,44 +400,44 @@ public class ClassGen extends AccessFlags implements Cloneable {
      * @param f field to remove
      */
     public void removeField( final Field f ) {
-        field_vec.remove(f);
+        fieldList.remove(f);
     }
 
 
     public String getClassName() {
-        return class_name;
+        return className;
     }
 
 
     public String getSuperclassName() {
-        return super_class_name;
+        return superClassName;
     }
 
 
     public String getFileName() {
-        return file_name;
+        return fileName;
     }
 
 
     public void setClassName( final String name ) {
-        class_name = name.replace('/', '.');
-        class_name_index = cp.addClass(name);
+        className = name.replace('/', '.');
+        classNameIndex = cp.addClass(name);
     }
 
 
     public void setSuperclassName( final String name ) {
-        super_class_name = name.replace('/', '.');
+        superClassName = name.replace('/', '.');
         superclass_name_index = cp.addClass(name);
     }
 
 
     public Method[] getMethods() {
-        return method_vec.toArray(new Method[method_vec.size()]);
+        return methodList.toArray(new Method[methodList.size()]);
     }
 
 
     public void setMethods( final Method[] methods ) {
-        method_vec.clear();
+        methodList.clear();
         for (final Method method : methods) {
             addMethod(method);
         }
@@ -445,45 +445,45 @@ public class ClassGen extends AccessFlags implements Cloneable {
 
 
     public void setMethodAt( final Method method, final int pos ) {
-        method_vec.set(pos, method);
+        methodList.set(pos, method);
     }
 
 
     public Method getMethodAt( final int pos ) {
-        return method_vec.get(pos);
+        return methodList.get(pos);
     }
 
 
     public String[] getInterfaceNames() {
-        final int size = interface_vec.size();
+        final int size = interfaceList.size();
         final String[] interfaces = new String[size];
-        interface_vec.toArray(interfaces);
+        interfaceList.toArray(interfaces);
         return interfaces;
     }
 
 
     public int[] getInterfaces() {
-        final int size = interface_vec.size();
+        final int size = interfaceList.size();
         final int[] interfaces = new int[size];
         for (int i = 0; i < size; i++) {
-            interfaces[i] = cp.addClass(interface_vec.get(i));
+            interfaces[i] = cp.addClass(interfaceList.get(i));
         }
         return interfaces;
     }
 
 
     public Field[] getFields() {
-        return field_vec.toArray(new Field[field_vec.size()]);
+        return fieldList.toArray(new Field[fieldList.size()]);
     }
 
 
     public Attribute[] getAttributes() {
-        return attribute_vec.toArray(new Attribute[attribute_vec.size()]);
+        return attributeList.toArray(new Attribute[attributeList.size()]);
     }
 
     //  J5TODO: Should we make calling unpackAnnotations() lazy and put it in here?
     public AnnotationEntryGen[] getAnnotationEntries() {
-        return annotation_vec.toArray(new AnnotationEntryGen[annotation_vec.size()]);
+        return annotationList.toArray(new AnnotationEntryGen[annotationList.size()]);
     }
 
 
@@ -498,15 +498,15 @@ public class ClassGen extends AccessFlags implements Cloneable {
 
 
     public void setClassNameIndex( final int class_name_index ) {
-        this.class_name_index = class_name_index;
-        class_name = cp.getConstantPool().getConstantString(class_name_index,
+        this.classNameIndex = class_name_index;
+        className = cp.getConstantPool().getConstantString(class_name_index,
                 Const.CONSTANT_Class).replace('/', '.');
     }
 
 
     public void setSuperclassNameIndex( final int superclass_name_index ) {
         this.superclass_name_index = superclass_name_index;
-        super_class_name = cp.getConstantPool().getConstantString(superclass_name_index,
+        superClassName = cp.getConstantPool().getConstantString(superclass_name_index,
                 Const.CONSTANT_Class).replace('/', '.');
     }
 
@@ -517,7 +517,7 @@ public class ClassGen extends AccessFlags implements Cloneable {
 
 
     public int getClassNameIndex() {
-        return class_name_index;
+        return classNameIndex;
     }
 
     private List<ClassObserver> observers;
@@ -569,7 +569,7 @@ public class ClassGen extends AccessFlags implements Cloneable {
      * @return Comparison strategy object
      */
     public static BCELComparator getComparator() {
-        return _cmp;
+        return bcelComparator;
     }
 
 
@@ -577,7 +577,7 @@ public class ClassGen extends AccessFlags implements Cloneable {
      * @param comparator Comparison strategy object
      */
     public static void setComparator( final BCELComparator comparator ) {
-        _cmp = comparator;
+        bcelComparator = comparator;
     }
 
 
@@ -590,7 +590,7 @@ public class ClassGen extends AccessFlags implements Cloneable {
      */
     @Override
     public boolean equals( final Object obj ) {
-        return _cmp.equals(this, obj);
+        return bcelComparator.equals(this, obj);
     }
 
 
@@ -602,6 +602,6 @@ public class ClassGen extends AccessFlags implements Cloneable {
      */
     @Override
     public int hashCode() {
-        return _cmp.hashCode(this);
+        return bcelComparator.hashCode(this);
     }
 }
