@@ -365,8 +365,8 @@ public class ClassPath implements Closeable {
         public void close() throws IOException {
             if (modules != null) {
                 // don't use a for each loop to avoid creating an iterator for the GC to collect.
-                for (int i = 0; i < modules.length; i++) {
-                    modules[i].close();
+                for (JrtModule module : modules) {
+                    module.close();
                 }
             }
             if (modularRuntimeImage != null) {
@@ -377,8 +377,8 @@ public class ClassPath implements Closeable {
         @Override
         ClassFile getClassFile(final String name, final String suffix) throws IOException {
             // don't use a for each loop to avoid creating an iterator for the GC to collect.
-            for (int i = 0; i < modules.length; i++) {
-                final ClassFile classFile = modules[i].getClassFile(name, suffix);
+            for (JrtModule module : modules) {
+                final ClassFile classFile = module.getClassFile(name, suffix);
                 if (classFile != null) {
                     return classFile;
                 }
@@ -389,8 +389,8 @@ public class ClassPath implements Closeable {
         @Override
         URL getResource(final String name) {
             // don't use a for each loop to avoid creating an iterator for the GC to collect.
-            for (int i = 0; i < modules.length; i++) {
-                final URL url = modules[i].getResource(name);
+            for (JrtModule module : modules) {
+                final URL url = module.getResource(name);
                 if (url != null) {
                     return url;
                 }
@@ -401,8 +401,8 @@ public class ClassPath implements Closeable {
         @Override
         InputStream getResourceAsStream(final String name) {
             // don't use a for each loop to avoid creating an iterator for the GC to collect.
-            for (int i = 0; i < modules.length; i++) {
-                final InputStream inputStream = modules[i].getResourceAsStream(name);
+            for (JrtModule module : modules) {
+                final InputStream inputStream = module.getResourceAsStream(name);
                 if (inputStream != null) {
                     return inputStream;
                 }
@@ -451,8 +451,8 @@ public class ClassPath implements Closeable {
         final File modulesDir = new File(modulesPath);
         if (modulesDir.exists()) {
             final String[] modules = modulesDir.list(MODULES_FILTER);
-            for (int i = 0; i < modules.length; i++) {
-                list.add(modulesDir.getPath() + File.separatorChar + modules[i]);
+            for (String module : modules) {
+                list.add(modulesDir.getPath() + File.separatorChar + module);
             }
         }
     }
