@@ -69,7 +69,7 @@ public class InstructionFinder {
     private static final int NO_OPCODES = 256; // Potential number, some are not used
     private static final Map<String, String> map = new HashMap<>();
     private final InstructionList il;
-    private String il_string; // instruction list as string
+    private String ilString; // instruction list as string
     private InstructionHandle[] handles; // map instruction
 
 
@@ -96,7 +96,7 @@ public class InstructionFinder {
         for (int i = 0; i < size; i++) {
             buf[i] = makeChar(handles[i].getInstruction().getOpcode());
         }
-        il_string = new String(buf);
+        ilString = new String(buf);
     }
 
 
@@ -117,7 +117,7 @@ public class InstructionFinder {
                 return "" + makeChar(i);
             }
         }
-        throw new RuntimeException("Instruction unknown: " + pattern);
+        throw new IllegalArgumentException("Instruction unknown: " + pattern);
     }
 
 
@@ -217,8 +217,8 @@ public class InstructionFinder {
         }
         final Pattern regex = Pattern.compile(search);
         final List<InstructionHandle[]> matches = new ArrayList<>();
-        final Matcher matcher = regex.matcher(il_string);
-        while (start < il_string.length() && matcher.find(start)) {
+        final Matcher matcher = regex.matcher(ilString);
+        while (start < ilString.length() && matcher.find(start)) {
             final int startExpr = matcher.start();
             final int endExpr = matcher.end();
             final int lenExpr = endExpr - startExpr;
