@@ -74,26 +74,68 @@ public final class Pass3bVerifier extends PassVerifier{
      * time, an InstructionContext object will get the current information
      * we have about its symbolic execution predecessors.
      */
-    private static final class InstructionContextQueue{
+    private static final class InstructionContextQueue {
+        // The following two fields together represent the queue.
+        /** The first elements from pairs in the queue. */
         private final List<InstructionContext> ics = new Vector<>();
+        /** The second elements from pairs in the queue. */
         private final List<ArrayList<InstructionContext>> ecs = new Vector<>();
+
+        /**
+         * Adds an (InstructionContext, ExecutionChain) pair to this queue.
+         *
+         * @param ic the InstructionContext
+         * @param executionChain the ExecutionChain
+         */
         public void add(final InstructionContext ic, final ArrayList<InstructionContext> executionChain) {
             ics.add(ic);
             ecs.add(executionChain);
         }
+
+        /**
+         * Tests if InstructionContext queue is empty.
+         *
+         * @return true if the InstructionContext queue is empty.
+         */
         public boolean isEmpty() {
             return ics.isEmpty();
         }
+
+        /**
+         * Removes a specific (InstructionContext, ExecutionChain) pair from their respective queues.
+         *
+         * @param i the index of the items to be removed
+         */
         public void remove(final int i) {
             ics.remove(i);
             ecs.remove(i);
         }
+
+        /**
+         * Gets a specific InstructionContext from the queue.
+         *
+         * @param i the index of the item to be fetched
+         * @return the indicated InstructionContext
+         */
         public InstructionContext getIC(final int i) {
             return ics.get(i);
         }
+
+        /**
+         * Gets a specific ExecutionChain from the queue.
+         *
+         * @param i the index of the item to be fetched
+         * @return the indicated ExecutionChain
+         */
         public ArrayList<InstructionContext> getEC(final int i) {
             return ecs.get(i);
         }
+
+        /**
+         * Gets the size of the InstructionContext queue.
+         *
+         * @return the size of the InstructionQueue
+         */
         public int size() {
             return ics.size();
         }
@@ -106,7 +148,7 @@ public final class Pass3bVerifier extends PassVerifier{
     private final Verifier myOwner;
 
     /** The method number to verify. */
-    private final int method_no;
+    private final int methodNo;
 
     /**
      * This class should only be instantiated by a Verifier.
@@ -115,15 +157,15 @@ public final class Pass3bVerifier extends PassVerifier{
      */
     public Pass3bVerifier(final Verifier owner, final int method_no) {
         myOwner = owner;
-        this.method_no = method_no;
+        this.methodNo = method_no;
     }
 
     /**
      * Whenever the outgoing frame
      * situation of an InstructionContext changes, all its successors are
      * put [back] into the queue [as if they were unvisited].
-   * The proof of termination is about the existence of a
-   * fix point of frame merging.
+     * The proof of termination is about the existence of a
+     * fix point of frame merging.
      */
     private void circulationPump(final MethodGen m,final ControlFlowGraph cfg, final InstructionContext start,
             final Frame vanillaFrame, final InstConstraintVisitor icv, final ExecutionVisitor ev) {
@@ -281,7 +323,7 @@ public final class Pass3bVerifier extends PassVerifier{
                             }
                         } catch (final ClassNotFoundException e) {
                             // Don't know what do do now, so raise RuntimeException
-                            throw new RuntimeException(e);
+                            throw new IllegalArgumentException(e);
                         }
                     } else if (!returnedType.equals(m.getReturnType().normalizeForStackOrLocal())) {
                         invalidReturnTypeError(returnedType, m);
@@ -293,7 +335,10 @@ public final class Pass3bVerifier extends PassVerifier{
      }
 
     /**
-     * Throws an exception indicating the returned type is not compatible with the return type of the given method
+     * Throws an exception indicating the returned type is not compatible with the return type of the given method.
+     *
+     * @param returnedType the type of the returned expression
+     * @param m the method we are processing
      * @throws StructuralCodeConstraintException always
      * @since 6.0
      */
@@ -305,16 +350,16 @@ public final class Pass3bVerifier extends PassVerifier{
     /**
      * Pass 3b implements the data flow analysis as described in the Java Virtual
      * Machine Specification, Second Edition.
-      * Later versions will use LocalVariablesInfo objects to verify if the
-      * verifier-inferred types and the class file's debug information (LocalVariables
-      * attributes) match [TODO].
-      *
-      * @see org.apache.bcel.verifier.statics.LocalVariablesInfo
-      * @see org.apache.bcel.verifier.statics.Pass2Verifier#getLocalVariablesInfo(int)
-      */
+     * Later versions will use LocalVariablesInfo objects to verify if the
+     * verifier-inferred types and the class file's debug information (LocalVariables
+     * attributes) match [TODO].
+     *
+     * @see org.apache.bcel.verifier.statics.LocalVariablesInfo
+     * @see org.apache.bcel.verifier.statics.Pass2Verifier#getLocalVariablesInfo(int)
+     */
     @Override
     public VerificationResult do_verify() {
-        if (! myOwner.doPass3a(method_no).equals(VerificationResult.VR_OK)) {
+        if (! myOwner.doPass3a(methodNo).equals(VerificationResult.VR_OK)) {
             return VerificationResult.VR_NOTYET;
         }
 
@@ -336,11 +381,11 @@ public final class Pass3bVerifier extends PassVerifier{
         final ExecutionVisitor ev = new ExecutionVisitor();
         ev.setConstantPoolGen(constantPoolGen);
 
-        final Method[] methods = jc.getMethods(); // Method no "method_no" exists, we ran Pass3a before on it!
+        final Method[] methods = jc.getMethods(); // Method no "methodNo" exists, we ran Pass3a before on it!
 
         try{
 
-            final MethodGen mg = new MethodGen(methods[method_no], myOwner.getClassName(), constantPoolGen);
+            final MethodGen mg = new MethodGen(methods[methodNo], myOwner.getClassName(), constantPoolGen);
 
             icv.setMethodGen(mg);
 
@@ -378,7 +423,7 @@ public final class Pass3bVerifier extends PassVerifier{
             }
         }
         catch (final VerifierConstraintViolatedException ce) {
-            ce.extendMessage("Constraint violated in method '"+methods[method_no]+"':\n","");
+            ce.extendMessage("Constraint violated in method '"+methods[methodNo]+"':\n","");
             return new VerificationResult(VerificationResult.VERIFIED_REJECTED, ce.getMessage());
         }
         catch (final RuntimeException re) {
@@ -389,13 +434,13 @@ public final class Pass3bVerifier extends PassVerifier{
             re.printStackTrace(pw);
 
             throw new AssertionViolatedException("Some RuntimeException occured while verify()ing class '"+jc.getClassName()+
-                "', method '"+methods[method_no]+"'. Original RuntimeException's stack trace:\n---\n"+sw+"---\n", re);
+                "', method '"+methods[methodNo]+"'. Original RuntimeException's stack trace:\n---\n"+sw+"---\n", re);
         }
         return VerificationResult.VR_OK;
     }
 
     /** Returns the method number as supplied when instantiating. */
     public int getMethodNo() {
-        return method_no;
+        return methodNo;
     }
 }
